DefinitionBlock ("", "DSDT", 3, "APPLE", "iMac", 0x00410002)
{
    Scope (\)
    {
        OperationRegion (PMIO, SystemIO, 0x1800, 0x80)
        Field (PMIO, ByteAcc, NoLock, Preserve)
        {
            Offset (0x42), 
                ,   1, 
            GPEC,   1
        }

        OperationRegion (GNVS, SystemMemory, 0xDDE5CC18, 0x7D)
        Field (GNVS, AnyAcc, Lock, Preserve)
        {
            Offset (0x7B), 
            ECON,   8, 
            GPIC,   8
        }

        OperationRegion (RCRB, SystemMemory, 0xFED1C000, 0x4000)
        Field (RCRB, DWordAcc, Lock, Preserve)
        {
            Offset (0x3419), 
                ,   5, 
            EH2D,   1,  // EH2D: EHCI #2 disable
                ,   1, 
            EH1D,   1,  // EH1D: EHCI #1 disable
                ,   3, 
            RP4D,   1   // RP4D: Root Port 4 disable
        }
    }

    Scope (_PR)
    {
        Processor (CPU0, 0x01, 0x00001810, 0x06)
        {
        }

        Processor (CPU1, 0x02, 0x00001810, 0x06)
        {
        }
        
        Processor (CPU2, 0x03, 0x00001810, 0x06)
        {
        }
        
        Processor (CPU3, 0x04, 0x00001810, 0x06)
        {
        }
    }

    Scope (_SB)
    {
        Method (_INI, 0, NotSerialized)  // _INI: Initialize
        {
            INI ()
        }

        Device (PWRB)
        {
            Name (_HID, EisaId ("PNP0C0C") /* Power Button Device */)  // _HID: Hardware ID
        }
    }

    Scope (_GPE)
    {
        Method (_L09, 0, NotSerialized)  // _Lxx: Level-Triggered GPE
        {
            Notify (\_SB.PCI0.XHC, 0x02) // Device Wake
        }
    }

    Device (_SB.PCI0)
    {
        Name (_HID, EisaId ("PNP0A08") /* PCI Express Bus */)  // _HID: Hardware ID
        Name (_CID, EisaId ("PNP0A03") /* PCI Bus */)  // _CID: Compatible ID
        Name (_ADR, Zero)  // _ADR: Address
        Name (_BBN, Zero)  // _BBN: BIOS Bus Number
        
        Method (_PRT, 0, NotSerialized)  // _PRT: PCI Routing Table
        {
            Return (PRT0) /* \PRT0 */
        }

        Method (_CRS, 0, NotSerialized)  // _CRS: Current Resource Settings
        {
            Return (CRS0) /* \CRS0 */
        }

        Device (MCHC)
        {
            Name (_ADR, Zero)  // _ADR: Address
        }

        Device (MEI)
        {
            Name (_ADR, 0x00160000)  // _ADR: Address
        }

        Device (PDRC)
        {
            Name (_HID, EisaId ("PNP0C02") /* PNP Motherboard Resources */)  // _HID: Hardware ID
            Name (_UID, One)  // _UID: Unique ID
            
            Method (_CRS, 0, NotSerialized)  // _CRS: Current Resource Settings
            {
                Return (CRS1) /* \CRS1 */
            }
        }

        Device (P0P2)
        {
            Name (_ADR, 0x00010000)  // _ADR: Address
            Name (_STA, 0x0F)  // _STA: Status
            Name (_S3D, 0x03)  // _S3D: S3 Device State
            
            Method (_PS0, 0, NotSerialized)  // _PS0: Power State 0
            {
            }

            Method (_PS3, 0, NotSerialized)  // _PS3: Power State 3
            {
            }

            Method (_PRT, 0, NotSerialized)  // _PRT: PCI Routing Table
            {
                Return (PRT1) /* \PRT1 */
            }

            Device (GFX0)
            {
                Name (_ADR, Zero)  // _ADR: Address
            }

            Device (HDAU)
            {
                Name (_ADR, One)  // _ADR: Address
            }
        }

        Device (RP01)
        {
            Name (_ADR, 0x001C0000)  // _ADR: Address
            Name (_STA, 0x0F)  // _STA: Status
            Name (_S3D, 0x03)  // _S3D: S3 Device State
            
            Method (_PRT, 0, NotSerialized)  // _PRT: PCI Routing Table
            {
                Return (PRT2) /* \PRT2 */
            }
        }

        Device (RP03)
        {
            Name (_ADR, 0x001C0002)  // _ADR: Address
            Name (_STA, 0x0F)  // _STA: Status
            Name (_S3D, 0x03)  // _S3D: S3 Device State
            
            Method (_PRT, 0, NotSerialized)  // _PRT: PCI Routing Table
            {
                Return (PRT3) /* \PRT3 */
            }

            Device (GIGE)
            {
                Name (_ADR, Zero)  // _ADR: Address
                Name (_STA, 0x0F)  // _STA: Status
            }
        }

        Device (RP04)
        {
            Name (_ADR, 0x001C0003)  // _ADR: Address
            Name (_STA, Zero)  // _STA: Status
            Name (_S3D, 0x03)  // _S3D: S3 Device State
            
            Method (_PRT, 0, NotSerialized)  // _PRT: PCI Routing Table
            {
                Return (PRT4) /* \PRT4 */
            }
        }

        Device (SATA)
        {
            Name (_ADR, 0x001F0002)  // _ADR: Address
            
            Device (PRT0) {
            
                Name (_ADR, 0x00)  // _ADR: Address
                
                Method (_DSM, 4, NotSerialized)  // _DSM: Device-Specific Method
                {
                    If ((Arg2 == Zero))
                    {
                        Return (Buffer (One) { 0x03 })
                    }

                    Return (Package ()
                    {
                        "@0,name",  "SSD"
                    })
                }
                
            }
            
            Device (PRT4) {
            
                Name (_ADR, 0x04)  // _ADR: Address
                
            }
            
            Device (PRT5) {
            
                Name (_ADR, 0x05)  // _ADR: Address
                
            }
            
            
        }

        Device (SBUS)
        {
            Name (_ADR, 0x001F0003)  // _ADR: Address
            Name (_STA, One)  // _STA: Status
            
            Device (BUS0)
            {
                Name (_CID, "smbus")  // _CID: Compatible ID
                Name (_ADR, Zero)  // _ADR: Address
            }

            Device (BUS1)
            {
                Name (_CID, "smbus")  // _CID: Compatible ID
                Name (_ADR, One)  // _ADR: Address
            }
        }

        Device (XHC)
        {
            Name (_ADR, 0x00140000)  // _ADR: Address
            Name (_S3D, 0x03)  // _S3D: S3 Device State
            
            Method (_PSW, 1, NotSerialized)  // _PSW: Power State Wake
            {
            }

            Name (_PRW, Package (0x02)  // _PRW: Power Resources for Wake
            {
                0x0D, 
                0x03
            })
            
            Method (_PS0, 0, NotSerialized)  // _PS0: Power State 0
            {
            }

            Method (_PS3, 0, NotSerialized)  // _PS3: Power State 3
            {
            }

            Scope (\)
            {
                Name (UPC2, Package (0x04)
                {
                    0xFF, 
                    Zero, 
                    Zero, 
                    Zero
                })
                
                Name (UPC3, Package (0x04)
                {
                    0xFF, 
                    0x03, 
                    Zero, 
                    Zero
                })
                
                Name (UPLD, Package (One)
                {
                    Buffer (0x14)
                    {
                        /* 0000 */  0x81, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  // ........
                        /* 0008 */  0x31, 0x1C, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  // 1.......
                        /* 0010 */  0x00, 0x00, 0x00, 0x00                           // ....
                    }
                })
            }

            Device (RHUB)
            {
                Name (_ADR, Zero)  // _ADR: Address
                Device (HS01)
                {
                    Name (_ADR, 0x03)  // _ADR: Address
                    
                    Method (_UPC, 0, Serialized)  // _UPC: USB Port Capabilities
                    {
                        Return (UPC2) /* \UPC2 */
                    }

                    Method (_PLD, 0, Serialized)  // _PLD: Physical Location of Device
                    {
                        Return (UPLD) /* \UPLD */
                    }
                }

                Device (HS02)
                {
                    Name (_ADR, 0x04)  // _ADR: Address
                    
                    Method (_UPC, 0, Serialized)  // _UPC: USB Port Capabilities
                    {
                        Return (UPC2) /* \UPC2 */
                    }

                    Method (_PLD, 0, Serialized)  // _PLD: Physical Location of Device
                    {
                        Return (UPLD) /* \UPLD */
                    }
                }

                Device (HS03)
                {
                    Name (_ADR, 0x08)  // _ADR: Address
                    Name (_RMV, Zero)  // _RMV: Removal Status
                    
                    Name (_UPC, Package (0x04)  // _UPC: USB Port Capabilities
                    {
                        0xFF, 
                        0xFF, 
                        Zero, 
                        Zero
                    })
                    
                    Method (_PLD, 0, Serialized)  // _PLD: Physical Location of Device
                    {
                        Return (UPLD) /* \UPLD */
                    }
                }

                Device (HS04)
                {
                    Name (_ADR, 0x09)  // _ADR: Address
                    
                    Method (_UPC, 0, Serialized)  // _UPC: USB Port Capabilities
                    {
                        Return (UPC3) /* \UPC3 */
                    }

                    Method (_PLD, 0, Serialized)  // _PLD: Physical Location of Device
                    {
                        Return (UPLD) /* \UPLD */
                    }
                }

                Device (HS05)
                {
                    Name (_ADR, 0x0A)  // _ADR: Address
                    
                    Method (_UPC, 0, Serialized)  // _UPC: USB Port Capabilities
                    {
                        Return (UPC3) /* \UPC3 */
                    }

                    Method (_PLD, 0, Serialized)  // _PLD: Physical Location of Device
                    {
                        Return (UPLD) /* \UPLD */
                    }
                }

                Device (SSP1)
                {
                    Name (_ADR, 0x10)  // _ADR: Address
                    
                    Method (_UPC, 0, Serialized)  // _UPC: USB Port Capabilities
                    {
                        Return (UPC3) /* \UPC3 */
                    }

                    Method (_PLD, 0, Serialized)  // _PLD: Physical Location of Device
                    {
                        Return (UPLD) /* \UPLD */
                    }
                }

                Device (SSP2)
                {
                    Name (_ADR, 0x11)  // _ADR: Address
                    
                    Method (_UPC, 0, Serialized)  // _UPC: USB Port Capabilities
                    {
                        Return (UPC3) /* \UPC3 */
                    }

                    Method (_PLD, 0, Serialized)  // _PLD: Physical Location of Device
                    {
                        Return (UPLD) /* \UPLD */
                    }
                }
            }
        }
    }

    Device (_SB.PCI0.LPCB)
    {
        Method (_DSM, 4, NotSerialized)  // _DSM: Device-Specific Method
        {
            If ((Arg2 == Zero))
            {
                Return (Buffer (One) { 0x03 })
            }

            Return (Package ()
            {
                "compatible",  "pci8086,8c44"
            })
        }
        
        Name (_ADR, 0x001F0000)  // _ADR: Address
              
        Name (PMBS, 0x1800)   // PMBase Offset
        OperationRegion (SMIE, SystemIO, PMBS, 0x04)
        Field (SMIE, ByteAcc, NoLock, Preserve)
        {
                ,   10, 
            RTCS,   1     // RTC Status (RTC_STS)
        }

        Name (SMCR, 0x1830)   // SMI_EN—SMI Control and Enable Register Offset
        OperationRegion (SLPR, SystemIO, SMCR, 0x04)
        Field (SLPR, ByteAcc, NoLock, Preserve)
        {
                ,   4, 
            SLPE,   1,    // SLP_SMI_EN
                ,   26, 
            SLPX,   1     // xHCI SMI Enable (xHCI _SMI_EN)
        }

        Device (DMAC)
        {
            Name (_HID, EisaId ("PNP0200") /* PC-class DMA Controller */)  // _HID: Hardware ID
            
            Method (_CRS, 0, NotSerialized)  // _CRS: Current Resource Settings
            {
                Return (CRS2) /* \CRS2 */
            }
        }

        Device (HPET)
        {
            Name (_HID, EisaId ("PNP0103") /* HPET System Timer */)  // _HID: Hardware ID
            Name (_STA, 0x0B)  // _STA: Status
            
            Method (_CRS, 0, NotSerialized)  // _CRS: Current Resource Settings
            {
                Return (CRS3) /* \CRS3 */
            }
        }

        Device (IPIC)
        {
            Name (_HID, EisaId ("PNP0000") /* 8259-compatible Programmable Interrupt Controller */)  // _HID: Hardware ID
            
            Method (_CRS, 0, NotSerialized)  // _CRS: Current Resource Settings
            {
                Return (CRS4) /* \CRS4 */
            }
        }

        Device (MATH)
        {
            Name (_HID, EisaId ("PNP0C04") /* x87-compatible Floating Point Processing Unit */)  // _HID: Hardware ID
            
            Method (_CRS, 0, NotSerialized)  // _CRS: Current Resource Settings
            {
                Return (CRS6) /* \CRS6 */
            }
        }

        Device (LDRC)
        {
            Name (_HID, EisaId ("PNP0C02") /* PNP Motherboard Resources */)  // _HID: Hardware ID
            Name (_UID, 0x02)  // _UID: Unique ID
            
            Method (_CRS, 0, NotSerialized)  // _CRS: Current Resource Settings
            {
                Return (CRS5) /* \CRS5 */
            }
        }

        Device (RTC)
        {
            Name (_HID, EisaId ("PNP0B00") /* AT Real-Time Clock */)  // _HID: Hardware ID
            
            Method (_CRS, 0, NotSerialized)  // _CRS: Current Resource Settings
            {
                Return (CRS8) /* \CRS8 */
            }
        }

        Device (TIMR)
        {
            Name (_HID, EisaId ("PNP0100") /* PC-class System Timer */)  // _HID: Hardware ID
            
            Method (_CRS, 0, NotSerialized)  // _CRS: Current Resource Settings
            {
                Return (CRS9) /* \CRS9 */
            }
        }

        Device (EC)
        {
            Name (_HID, EisaId ("PNP0C09") /* Embedded Controller Device */)  // _HID: Hardware ID
            Name (CMDR, Zero)
            
            Method (ECMD, 1, Serialized)
            {
                If (ECON)
                {
                    While (CMDR)
                    {
                        Stall (0x14)
                    }

                    CMDR = Arg0
                }
            }

            Method (ECRD, 1, Serialized)
            {
                Return (DerefOf (Arg0))
            }

            Method (ECWT, 2, Serialized)
            {
                Arg1 = Arg0
            }
            
            Name (_PRW, Package (0x02)  // _PRW: Power Resources for Wake
            {
                0x23, 
                0x03
            })
        }
    }

    Method (_SB.PCI0.LPCB.SPTS, 0, NotSerialized)
    {
        SLPX = One  // xHCI SMI Enable (xHCI _SMI_EN)
        SLPE = One  // SLP_SMI_EN
    }

    Method (_SB.PCI0.LPCB.SWAK, 0, NotSerialized)
    {
        SLPE = Zero // SLP_SMI_EN
        If (RTCS) {}  // RTC Status (RTC_STS)
        Else
        {
            Notify (PWRB, 0x02) // Device Wake
        }
    }

    Scope (\)
    {
        Method (_PIC, 1, NotSerialized)  // _PIC: Interrupt Model
        {
            GPIC = One    // 0 = PIC, 1 = APIC, 2 = SAPIC
        }

        Method (_PTS, 1, NotSerialized)  // _PTS: Prepare To Sleep
        {
            If (((Arg0 == 0x03) || (Arg0 == 0x04)))
            {
                \_SB.PCI0.LPCB.SPTS ()
            }

            If ((Arg0 == 0x05))
            {
                PTS5 ()
            }
        }

        Method (_WAK, 1, Serialized)  // _WAK: Wake
        {
            \_SB.PCI0.LPCB.SWAK ()
            Return (Package (0x02)
            {
                Zero, 
                Zero
            })
        }

        Method (INI, 0, NotSerialized)
        {
            EH1D = One  // EH1D: EHCI #1 disable
            EH2D = One  // EH2D: EHCI #2 disable
            RP4D = One  // RP4D: Root Port 4 disable
        }

        Method (PTS5, 0, NotSerialized)
        {
            EH1D = Zero  // EH1D: EHCI #1 disable
            EH2D = Zero  // EH2D: EHCI #2 disable
            RP4D = Zero  // RP4D: Root Port 4 disable
        }
    }

    Scope (\)
    {
        Name (_S0, Package (0x04)  // _S0_: S0 System State
        {
            Zero, 
            Zero, 
            Zero, 
            Zero
        })
        
        Name (_S3, Package (0x04)  // _S3_: S3 System State
        {
            0x05, 
            Zero, 
            Zero, 
            Zero
        })
        
        Name (_S4, Package (0x04)  // _S4_: S4 System State
        {
            0x07, 
            Zero, 
            Zero, 
            Zero
        })
        
        Name (_S5, Package (0x04)  // _S5_: S5 System State
        {
            0x07, 
            Zero, 
            Zero, 
            Zero
        })
    }

    Name (CRS0, ResourceTemplate ()
    {
        IO (Decode16,
            0x0CF8,             // Range Minimum
            0x0CF8,             // Range Maximum
            0x01,               // Alignment
            0x08,               // Length
            )
        WordBusNumber (ResourceProducer, MinFixed, MaxFixed, PosDecode,
            0x0000,             // Granularity
            0x0000,             // Range Minimum
            0x003E,             // Range Maximum
            0x0000,             // Translation Offset
            0x003F,             // Length
            ,, )
        DWordIO (ResourceProducer, MinFixed, MaxFixed, PosDecode, EntireRange,
            0x00000000,         // Granularity
            0x00000000,         // Range Minimum
            0x00000CF7,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00000CF8,         // Length
            ,, , TypeStatic, DenseTranslation)
        DWordIO (ResourceProducer, MinFixed, MaxFixed, PosDecode, EntireRange,
            0x00000000,         // Granularity
            0x00000D00,         // Range Minimum
            0x0000FFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x0000F300,         // Length
            ,, , TypeStatic, DenseTranslation)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadWrite,
            0x00000000,         // Granularity
            0x000A0000,         // Range Minimum
            0x000BFFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00020000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadOnly,
            0x00000000,         // Granularity
            0x000C0000,         // Range Minimum
            0x000C3FFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadOnly,
            0x00000000,         // Granularity
            0x000C4000,         // Range Minimum
            0x000C7FFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadOnly,
            0x00000000,         // Granularity
            0x000C8000,         // Range Minimum
            0x000CBFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadOnly,
            0x00000000,         // Granularity
            0x000CC000,         // Range Minimum
            0x000CFFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadWrite,
            0x00000000,         // Granularity
            0x000D0000,         // Range Minimum
            0x000D3FFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadWrite,
            0x00000000,         // Granularity
            0x000D4000,         // Range Minimum
            0x000D7FFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadWrite,
            0x00000000,         // Granularity
            0x000D8000,         // Range Minimum
            0x000DBFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadWrite,
            0x00000000,         // Granularity
            0x000DC000,         // Range Minimum
            0x000DFFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadWrite,
            0x00000000,         // Granularity
            0x000E0000,         // Range Minimum
            0x000E3FFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadWrite,
            0x00000000,         // Granularity
            0x000E4000,         // Range Minimum
            0x000E7FFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadOnly,
            0x00000000,         // Granularity
            0x000E8000,         // Range Minimum
            0x000EBFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadOnly,
            0x00000000,         // Granularity
            0x000EC000,         // Range Minimum
            0x000EFFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00004000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadOnly,
            0x00000000,         // Granularity
            0x000F0000,         // Range Minimum
            0x000FFFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x00010000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
        DWordMemory (ResourceProducer, PosDecode, MinFixed, MaxFixed, Cacheable, ReadWrite,
            0x00000000,         // Granularity
            0xBFA00000,         // Range Minimum
            0xFEAFFFFF,         // Range Maximum
            0x00000000,         // Translation Offset
            0x3F100000,         // Length
            ,, , AddressRangeMemory, TypeStatic)
    })
    Name (CRS1, ResourceTemplate ()
    {
        Memory32Fixed (ReadWrite,
            0xFED1C000,         // Address Base
            0x00004000,         // Address Length
            )
        Memory32Fixed (ReadWrite,
            0xFED10000,         // Address Base
            0x00008000,         // Address Length
            )
        Memory32Fixed (ReadWrite,
            0xFED18000,         // Address Base
            0x00001000,         // Address Length
            )
        Memory32Fixed (ReadWrite,
            0xFED19000,         // Address Base
            0x00001000,         // Address Length
            )
        Memory32Fixed (ReadWrite,
            0xF8000000,         // Address Base
            0x40000000,         // Address Length
            )
        Memory32Fixed (ReadWrite,
            0xFED20000,         // Address Base
            0x00020000,         // Address Length
            )
        Memory32Fixed (ReadOnly,
            0xFED90000,         // Address Base
            0x00004000,         // Address Length
            )
        Memory32Fixed (ReadWrite,
            0xFED45000,         // Address Base
            0x0004B000,         // Address Length
            )
        Memory32Fixed (ReadOnly,
            0xFF000000,         // Address Base
            0x01000000,         // Address Length
            )
        Memory32Fixed (ReadOnly,
            0xFEE00000,         // Address Base
            0x00100000,         // Address Length
            )
        Memory32Fixed (ReadWrite,
            0xF7FDF000,         // Address Base
            0x00001000,         // Address Length
            )
        Memory32Fixed (ReadWrite,
            0xF7FE0000,         // Address Base
            0x00010000,         // Address Length
            )
    })
    Name (CRS2, ResourceTemplate ()
    {
        IO (Decode16,
            0x0000,             // Range Minimum
            0x0000,             // Range Maximum
            0x01,               // Alignment
            0x20,               // Length
            )
        IO (Decode16,
            0x0081,             // Range Minimum
            0x0081,             // Range Maximum
            0x01,               // Alignment
            0x11,               // Length
            )
        IO (Decode16,
            0x0093,             // Range Minimum
            0x0093,             // Range Maximum
            0x01,               // Alignment
            0x0D,               // Length
            )
        IO (Decode16,
            0x00C0,             // Range Minimum
            0x00C0,             // Range Maximum
            0x01,               // Alignment
            0x20,               // Length
            )
        DMA (Compatibility, NotBusMaster, Transfer8_16, )
            {4}
    })
    Name (CRS3, ResourceTemplate ()
    {
        Memory32Fixed (ReadWrite,
            0xFED00000,         // Address Base
            0x00000400,         // Address Length
            )
        IRQNoFlags ()
            {0}
        IRQNoFlags ()
            {8}
    })
    Name (CRS4, ResourceTemplate ()
    {
        IO (Decode16,
            0x0020,             // Range Minimum
            0x0020,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x0024,             // Range Minimum
            0x0024,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x0028,             // Range Minimum
            0x0028,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x002C,             // Range Minimum
            0x002C,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x0030,             // Range Minimum
            0x0030,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x0034,             // Range Minimum
            0x0034,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x0038,             // Range Minimum
            0x0038,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x003C,             // Range Minimum
            0x003C,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x00A0,             // Range Minimum
            0x00A0,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x00A4,             // Range Minimum
            0x00A4,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x00A8,             // Range Minimum
            0x00A8,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x00AC,             // Range Minimum
            0x00AC,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x00B0,             // Range Minimum
            0x00B0,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x00B4,             // Range Minimum
            0x00B4,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x00B8,             // Range Minimum
            0x00B8,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x00BC,             // Range Minimum
            0x00BC,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x04D0,             // Range Minimum
            0x04D0,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IRQNoFlags ()
            {2}
    })
    Name (CRS5, ResourceTemplate ()
    {
        IO (Decode16,
            0x002E,             // Range Minimum
            0x002E,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x004E,             // Range Minimum
            0x004E,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x0061,             // Range Minimum
            0x0061,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x0063,             // Range Minimum
            0x0063,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x0065,             // Range Minimum
            0x0065,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x0067,             // Range Minimum
            0x0067,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x0070,             // Range Minimum
            0x0070,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x0080,             // Range Minimum
            0x0080,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x0092,             // Range Minimum
            0x0092,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x00B2,             // Range Minimum
            0x00B2,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x0680,             // Range Minimum
            0x0680,             // Range Maximum
            0x01,               // Alignment
            0x20,               // Length
            )
        IO (Decode16,
            0xFFFF,             // Range Minimum
            0xFFFF,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0xFFFF,             // Range Minimum
            0xFFFF,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0xFFFF,             // Range Minimum
            0xFFFF,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x1C00,             // Range Minimum
            0x1C00,             // Range Maximum
            0x01,               // Alignment
            0xFF,               // Length
            )
        IO (Decode16,
            0x1D00,             // Range Minimum
            0x1D00,             // Range Maximum
            0x01,               // Alignment
            0xFF,               // Length
            )
        IO (Decode16,
            0x1E00,             // Range Minimum
            0x1E00,             // Range Maximum
            0x01,               // Alignment
            0xFF,               // Length
            )
        IO (Decode16,
            0x1F00,             // Range Minimum
            0x1F00,             // Range Maximum
            0x01,               // Alignment
            0xFF,               // Length
            )
        IO (Decode16,
            0x1800,             // Range Minimum
            0x1800,             // Range Maximum
            0x01,               // Alignment
            0xFF,               // Length
            )
        IO (Decode16,
            0x164E,             // Range Minimum
            0x164E,             // Range Maximum
            0x01,               // Alignment
            0x02,               // Length
            )
    })
    Name (CRS6, ResourceTemplate ()
    {
        IO (Decode16,
            0x00F0,             // Range Minimum
            0x00F0,             // Range Maximum
            0x01,               // Alignment
            0x01,               // Length
            )
        IRQNoFlags ()
            {13}
    })
    Name (CRS7, ResourceTemplate ()
    {
        IO (Decode16,
            0x0010,             // Range Minimum
            0x0010,             // Range Maximum
            0x00,               // Alignment
            0x10,               // Length
            )
        IO (Decode16,
            0x0022,             // Range Minimum
            0x0022,             // Range Maximum
            0x00,               // Alignment
            0x1E,               // Length
            )
        IO (Decode16,
            0x0044,             // Range Minimum
            0x0044,             // Range Maximum
            0x00,               // Alignment
            0x1C,               // Length
            )
        IO (Decode16,
            0x0062,             // Range Minimum
            0x0062,             // Range Maximum
            0x00,               // Alignment
            0x02,               // Length
            )
        IO (Decode16,
            0x0065,             // Range Minimum
            0x0065,             // Range Maximum
            0x00,               // Alignment
            0x0B,               // Length
            )
        IO (Decode16,
            0x0072,             // Range Minimum
            0x0072,             // Range Maximum
            0x00,               // Alignment
            0x0E,               // Length
            )
        IO (Decode16,
            0x0080,             // Range Minimum
            0x0080,             // Range Maximum
            0x00,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x0084,             // Range Minimum
            0x0084,             // Range Maximum
            0x00,               // Alignment
            0x03,               // Length
            )
        IO (Decode16,
            0x0088,             // Range Minimum
            0x0088,             // Range Maximum
            0x00,               // Alignment
            0x01,               // Length
            )
        IO (Decode16,
            0x008C,             // Range Minimum
            0x008C,             // Range Maximum
            0x00,               // Alignment
            0x03,               // Length
            )
        IO (Decode16,
            0x0090,             // Range Minimum
            0x0090,             // Range Maximum
            0x00,               // Alignment
            0x10,               // Length
            )
        IO (Decode16,
            0x00A2,             // Range Minimum
            0x00A2,             // Range Maximum
            0x00,               // Alignment
            0x1E,               // Length
            )
        IO (Decode16,
            0x00E0,             // Range Minimum
            0x00E0,             // Range Maximum
            0x00,               // Alignment
            0x10,               // Length
            )
        IO (Decode16,
            0x04D0,             // Range Minimum
            0x04D0,             // Range Maximum
            0x00,               // Alignment
            0x02,               // Length
            )
    })
    Name (CRS8, ResourceTemplate ()
    {
        IO (Decode16,
            0x0070,             // Range Minimum
            0x0070,             // Range Maximum
            0x01,               // Alignment
            0x08,               // Length
            )
        IRQNoFlags ()
            {8}
    })
    Name (CRS9, ResourceTemplate ()
    {
        IO (Decode16,
            0x0040,             // Range Minimum
            0x0040,             // Range Maximum
            0x01,               // Alignment
            0x04,               // Length
            )
        IO (Decode16,
            0x0050,             // Range Minimum
            0x0050,             // Range Maximum
            0x10,               // Alignment
            0x04,               // Length
            )
        IRQNoFlags ()
            {0}
    })
    Name (PRT0, Package (0x1A)
    {
        Package (0x04)
        {
            0x001FFFFF, 
            Zero, 
            Zero, 
            0x15
        }, 

        Package (0x04)
        {
            0x001FFFFF, 
            One, 
            Zero, 
            0x13
        }, 

        Package (0x04)
        {
            0x001FFFFF, 
            0x02, 
            Zero, 
            0x12
        }, 

        Package (0x04)
        {
            0x001FFFFF, 
            0x03, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0x0014FFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0x001DFFFF, 
            Zero, 
            Zero, 
            0x17
        }, 

        Package (0x04)
        {
            0x001AFFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0x001BFFFF, 
            Zero, 
            Zero, 
            0x16
        }, 

        Package (0x04)
        {
            0x0016FFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0x0016FFFF, 
            One, 
            Zero, 
            0x13
        }, 

        Package (0x04)
        {
            0x0016FFFF, 
            0x02, 
            Zero, 
            0x12
        }, 

        Package (0x04)
        {
            0x0016FFFF, 
            0x03, 
            Zero, 
            0x11
        }, 

        Package (0x04)
        {
            0x001CFFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0x001CFFFF, 
            One, 
            Zero, 
            0x11
        }, 

        Package (0x04)
        {
            0x001CFFFF, 
            0x02, 
            Zero, 
            0x12
        }, 

        Package (0x04)
        {
            0x001CFFFF, 
            0x03, 
            Zero, 
            0x13
        }, 

        Package (0x04)
        {
            0x0001FFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0x0001FFFF, 
            One, 
            Zero, 
            0x11
        }, 

        Package (0x04)
        {
            0x0001FFFF, 
            0x02, 
            Zero, 
            0x12
        }, 

        Package (0x04)
        {
            0x0001FFFF, 
            0x03, 
            Zero, 
            0x13
        }, 

        Package (0x04)
        {
            0x0002FFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0x0003FFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0x0004FFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0x0004FFFF, 
            One, 
            Zero, 
            0x11
        }, 

        Package (0x04)
        {
            0x0004FFFF, 
            0x02, 
            Zero, 
            0x12
        }, 

        Package (0x04)
        {
            0x0004FFFF, 
            0x03, 
            Zero, 
            0x13
        }
    })
    Name (PRT1, Package (0x04)
    {
        Package (0x04)
        {
            0xFFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0xFFFF, 
            One, 
            Zero, 
            0x11
        }, 

        Package (0x04)
        {
            0xFFFF, 
            0x02, 
            Zero, 
            0x12
        }, 

        Package (0x04)
        {
            0xFFFF, 
            0x03, 
            Zero, 
            0x13
        }
    })
    Name (PRT2, Package (0x04)
    {
        Package (0x04)
        {
            0xFFFF, 
            Zero, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0xFFFF, 
            One, 
            Zero, 
            0x11
        }, 

        Package (0x04)
        {
            0xFFFF, 
            0x02, 
            Zero, 
            0x12
        }, 

        Package (0x04)
        {
            0xFFFF, 
            0x03, 
            Zero, 
            0x13
        }
    })
    Name (PRT3, Package (0x04)
    {
        Package (0x04)
        {
            0xFFFF, 
            Zero, 
            Zero, 
            0x12
        }, 

        Package (0x04)
        {
            0xFFFF, 
            One, 
            Zero, 
            0x13
        }, 

        Package (0x04)
        {
            0xFFFF, 
            0x02, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0xFFFF, 
            0x03, 
            Zero, 
            0x11
        }
    })
    Name (PRT4, Package (0x04)
    {
        Package (0x04)
        {
            0xFFFF, 
            Zero, 
            Zero, 
            0x13
        }, 

        Package (0x04)
        {
            0xFFFF, 
            One, 
            Zero, 
            0x10
        }, 

        Package (0x04)
        {
            0xFFFF, 
            0x02, 
            Zero, 
            0x11
        }, 

        Package (0x04)
        {
            0xFFFF, 
            0x03, 
            Zero, 
            0x12
        }
    })
}

